class Serialosc < Formula
  desc "Opensound control server for monome devices"
  homepage "https://github.com/monome/docs/blob/gh-pages/serialosc/osc.md"
  # pull from git tag to get submodules
  url "https://github.com/monome/serialosc.git",
      tag:      "v1.4.4",
      revision: "19ad3a211876c4434346ab2565eeec09cc949856"
  license "ISC"
  head "https://github.com/monome/serialosc.git", branch: "main"

  depends_on "confuse"
  depends_on "liblo"
  depends_on "libmonome"
  depends_on "libuv"

  uses_from_macos "python" => :build

  on_linux do
    depends_on "avahi"
    depends_on "systemd" # for libudev
  end

  # Uses fmemopen API (High Sierra) but defining a target macOS version of Leopard:
  # https://github.com/monome/serialosc/pull/71
  patch :DATA

  def install
    system "python3", "./waf", "configure", "--prefix=#{prefix}"
    system "python3", "./waf", "build"
    system "python3", "./waf", "install"
  end

  service do
    run [opt_bin/"serialoscd"]
    keep_alive true
    log_path var/"log/serialoscd.log"
    error_log_path var/"log/serialoscd.log"
  end

  test do
    assert_match version.to_s, shell_output("#{bin}/serialoscd -v")
  end
end
__END__
diff --git a/wscript b/wscript
index 5026c5c..8af6e84 100644
--- a/wscript
+++ b/wscript
@@ -272,8 +272,8 @@ def configure(conf):
 					'-Wl,--enable-stdcall-fixup'])
 		conf.env.append_unique("WINRCFLAGS", ["-O", "coff"])
 	elif conf.env.DEST_OS == "darwin":
-		conf.env.append_unique("CFLAGS", ["-mmacosx-version-min=10.5"])
-		conf.env.append_unique("LINKFLAGS", ["-mmacosx-version-min=10.5"])
+		conf.env.append_unique("CFLAGS", ["-mmacosx-version-min=10.13"])
+		conf.env.append_unique("LINKFLAGS", ["-mmacosx-version-min=10.13"])
 
 	if conf.options.disable_zeroconf:
 		conf.define("SOSC_NO_ZEROCONF", True)
